==> rflowcyt_1.8.0.tar.gz: rflowcyt/man/plotECDF.FCS.Rd <==
\name{plotECDF.FCS}
\alias{plotECDF.FCS}

\title{Create a empirical cumulative distribution plot for one (or more) parameter(s)
  of one (or more) FCS object(s)}

\description{
  Create a empirical cumulative distribution plot for one parameter
  of one (or more) FCS object(s).
}
\usage{
plotECDF.FCS(data, varpos, var.list, group.list, xlab, ylab,alternating=TRUE,legend.title=NULL,...)                      
}

\arguments{
  \item{data}{a list of fluorescent data from one (or more) FCS object(s)}

  \item{varpos}{the numerical column variable position of the data of
    the FCS object}

  \item{var.list}{conditioning variables}

  \item{group.list}{a variable or expression to be evaluated in the data
    frame specified by 'data', expected to act as a grouping variable
    within each panel, typically used to distinguish different groups by
    varying graphical parameters like color and line type}

  \item{xlab}{a title for the x axis}
  
  \item{ylab}{a title for the y axis}

  \item{alternating}{logical specifying whether axis labels should
               alternate from one side of the group of panels to the
               other (for more details see \code{\link{xyplot}})}

  \item{legend.title}{a title for the legend}

  \item{...}{any other arguments are passed to the \code{\link{xyplot}}
  function}
}  

\details{
  Other options from the functions \code{\link{xyplot}} from
  the\code{\link{lattice}} library.
}

\value{
 None.
}

\author{N. Le Meur}


\seealso{\code{\link{ecdf}},\code{\link{lattice}},
  \code{\link{xyplot}}}


\examples{
 require(rfcdmin)
 require(lattice)

 ##Example I:
 data(flowcyt.data)

 ##Draw an empirical cumulative density plot for the Foward scatter
 ##parameter of the different stains at a particular different time point
 ##(one panel per time point).
 plotECDF.FCS(flowcyt.data,varpos=c(1),var.list=c(paste("time",1:12,sep="")),group.list=paste("Stain",c(1:8),sep=""),main="ECDF plot of the FSC parameter for different stains across time points",lwd=2,cex=1.5,type="l")

 ##Example II:
 if (require(rfcdmin)) {
  ##Obtain the location of the fcs files 
  pathFiles<-system.file("bccrc", package="rfcdmin")
  drugFiles<-dir(pathFiles)

  ##Read a serie of FCS files
  drugData<-read.series.FCS(drugFiles,path=pathFiles,MY.DEBUG=FALSE)
  }

  ##Draw a empirical cumulative density plot for the Foward scatter
 ##parameter for the differents aliquots (of the same cell line)
 ##treated with different compounds. 
 plotECDF.FCS(drugData,varpos=c(1),var.list=c("Serie"),group.list=paste("compound",c(1:8),sep=""),main="ECDF plot for the aliquots treated with different compounds.",lwd=2,cex=1.5,type="l")
 }

\keyword{hplot}

==> rflowcyt_1.16.0.tar.gz: rflowcyt/man/plotECDF.FCS.Rd <==
\name{plotECDF.FCS}
\alias{plotECDF.FCS}

\title{Create a empirical cumulative distribution plot for one (or more) parameter(s)
  of one (or more) FCS object(s)}

\description{
  Create a empirical cumulative distribution plot for one parameter
  of one (or more) FCS object(s).
}
\usage{
plotECDF.FCS(data, varpos, var.list, group.list, xlab,
ylab,alternating=TRUE, legend.title=NULL,...)                      
}

\arguments{
  \item{data}{a list of fluorescent data from one (or more) FCS object(s)}

  \item{varpos}{the numerical column variable position of the data of
    the FCS object}

  \item{var.list}{conditioning variables}

  \item{group.list}{a variable or expression to be evaluated in the data
    frame specified by 'data', expected to act as a grouping variable
    within each panel, typically used to distinguish different groups by
    varying graphical parameters like color and line type}

  \item{xlab}{a title for the x axis}
  
  \item{ylab}{a title for the y axis}

  \item{alternating}{logical specifying whether axis labels should
               alternate from one side of the group of panels to the
               other (for more details see \code{\link[lattice]{xyplot}})}

  \item{legend.title}{a title for the legend}

  \item{...}{any other arguments are passed to the \code{\link[lattice]{xyplot}}
  function}
}  

\details{
  Other options from the functions \code{\link[lattice]{xyplot}} from
  the \code{\link[lattice]{lattice}} library.
}

\value{
 None.
}

\author{N. Le Meur}


\seealso{\code{\link{ecdf}},\code{\link[lattice]{lattice}},
  \code{\link[lattice]{xyplot}}}


\examples{
 require(rfcdmin)
 require(lattice)

 ##Example I:
 data(flowcyt.data)

 ##Draw an empirical cumulative density plot for the Foward scatter
 ##parameter of the different stains at a particular different time point
 ##(one panel per time point).
 plotECDF.FCS(flowcyt.data,varpos=c(1),var.list=c(paste("time",1:12,sep="")),group.list=paste("Stain",c(1:8),sep=""),main="ECDF plot of the FSC parameter for different stains across time points",lwd=2,cex=1.5,type="l")

 ##Example II:
 if (require(rfcdmin)) {
  ##Obtain the location of the fcs files 
  pathFiles<-system.file("bccrc", package="rfcdmin")
  drugFiles<-dir(pathFiles)

  ##Read a serie of FCS files
  drugData<-read.series.FCS(drugFiles,path=pathFiles,MY.DEBUG=FALSE)
  }

  ##Draw a empirical cumulative density plot for the Foward scatter
 ##parameter for the differents aliquots (of the same cell line)
 ##treated with different compounds. 
 plotECDF.FCS(drugData,varpos=c(1),var.list=c("Serie"),group.list=paste("compound",c(1:8),sep=""),main="ECDF plot for the aliquots treated with different compounds.",lwd=2,cex=1.5,type="l")
 }

\keyword{hplot}
